@@ -9,7 +9,6 @@
 #include "hdy-swipe-group.h"
 #include <gtk/gtk.h>
 #include "hdy-navigation-direction.h"
-#include "hdy-swipeable.h"
 #include "hdy-swipe-tracker-private.h"
 
 #define BUILDABLE_TAG_OBJECT "object"
@@ -17,6 +16,8 @@
 #define BUILDABLE_TAG_SWIPEABLES "swipeables"
 #define BUILDABLE_TAG_TEMPLATE "template"
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+
 /**
  * SECTION:hdy-swipe-group
  * @short_description: An object for syncing swipeable widgets.
@@ -46,7 +47,13 @@
  * </object>
  * ]|
  *
+ * #HdySwipeGroup has been deprecated, #HdyWindow and #HdyApplicationWindow
+ * allow using a single leaflet for both content and header bar, without the
+ * need to sync them.
+ *
  * Since: 0.0.12
+ *
+ * Deprecated: 1.4
  */
 
 struct _HdySwipeGroup
@@ -96,6 +103,8 @@ swipeable_destroyed (HdySwipeGroup *self,
  * Returns: The newly created #HdySwipeGroup object
  *
  * Since: 0.0.12
+ *
+ * Deprecated: 1.4
  */
 HdySwipeGroup *
 hdy_swipe_group_new (void)
@@ -105,7 +114,7 @@ hdy_swipe_group_new (void)
 
 static void
 child_switched_cb (HdySwipeGroup *self,
-                   uint           index,
+                   guint          index,
                    gint64         duration,
                    HdySwipeable  *swipeable)
 {
@@ -219,6 +228,8 @@ end_swipe_cb (HdySwipeGroup   *self,
  * be removed from the swipe group.
  *
  * Since: 0.0.12
+ *
+ * Deprecated: 1.4
  */
 void
 hdy_swipe_group_add_swipeable (HdySwipeGroup *self,
@@ -254,6 +265,8 @@ hdy_swipe_group_add_swipeable (HdySwipeGroup *self,
  * Removes a widget from a #HdySwipeGroup.
  *
  * Since: 0.0.12
+ *
+ * Deprecated: 1.4
  **/
 void
 hdy_swipe_group_remove_swipeable (HdySwipeGroup *self,
@@ -286,6 +299,8 @@ hdy_swipe_group_remove_swipeable (HdySwipeGroup *self,
  *   swipeables. The list is owned by libhandy and should not be modified.
  *
  * Since: 0.0.12
+ *
+ * Deprecated: 1.4
  **/
 GSList *
 hdy_swipe_group_get_swipeables (HdySwipeGroup *self)
@@ -485,7 +500,11 @@ swipe_group_start_element (GMarkupParseContext  *context,
 /* This has been copied and modified from gtksizegroup.c. */
 static const GMarkupParser swipe_group_parser =
   {
-    swipe_group_start_element
+    swipe_group_start_element,
+    NULL,
+    NULL,
+    NULL,
+    NULL
   };
 
 /* This has been copied and modified from gtksizegroup.c. */
@@ -567,3 +586,5 @@ hdy_swipe_group_buildable_init (GtkBuildableIface *iface)
   iface->custom_tag_start = hdy_swipe_group_buildable_custom_tag_start;
   iface->custom_finished = hdy_swipe_group_buildable_custom_finished;
 }
+
+G_GNUC_END_IGNORE_DEPRECATIONS
